""" parser functions """
import optparse  # pylint: disable=W4901


def add_entry_parser() -> optparse.OptionParser:
    """Parser for entry command."""
    parser = optparse.OptionParser(
        usage="main.py add-entry [options]\n" "Add pair to to the list"
    )
    parser.add_option(
        "-s", "--stock", dest="stock", help="Symbol of the stock to entry."
    )
    parser.add_option(
        "-d", "--date", dest="date", help="Date of the entry, please add as DD/MM/YYYY"
    )
    parser.add_option("-c", "--count", dest="count", help="Count of the stocks bought.")
    parser.add_option("-p", "--price", dest="price", help="Price of the stocks.")
    return parser


def import_parser() -> optparse.OptionParser:
    """Parser for import command"""
    parser = optparse.OptionParser(
        usage="main.py import-data [options]\n" "Import data from your custom files."
    )
    parser.add_option(
        "-e", "--entries", dest="entries", help="Path to your custom file with entries."
    )
    parser.add_option(
        "-p",
        "--portfolio",
        dest="portfolio",
        help="Path to your custom file with portfolio.",
    )
    parser.add_option(
        "-d",
        "--dividends",
        dest="dividends",
        help="Path to your custom file with dividends.",
    )
    parser.add_option(
        "-y",
        dest="confirmation",
        action="store_true",
        help="Flag to automatically confirm all actions as overwrite of your current datafiles",
        default=False,
    )

    parser.add_option(
        "--initialize",
        dest="initialize",
        action="store_true",
        help="Flag for initialization of basic data false, has to be used with -y, or it has no"
        "effect.",
        default=False,
    )

    return parser


def export_parser() -> optparse.OptionParser:
    """Parser for export command."""
    parser = optparse.OptionParser(
        usage="main.py import-data [options]\n"
        "Export data from your custom files to some"
        "directory."
    )
    parser.add_option(
        "-d", "--directory", dest="directory", help="Path to directory for the output."
    )

    return parser


def dividend_parser() -> optparse.OptionParser:
    """Parser for dividend command."""
    parser = optparse.OptionParser(
        usage="main.py add-entry [options]\n" "Add dividend entry to to the list"
    )
    parser.add_option(
        "-s", "--stock", dest="stock", help="Symbol of the stock for dividend."
    )
    parser.add_option(
        "-d",
        "--date",
        dest="date",
        help="Date of the dividend entry, please add as DD/MM/YYYY",
    )
    parser.add_option(
        "-a",
        "--amount",
        dest="amount",
        help="Amount of the earned money " "(in stock currency)",
    )
    return parser



""" Module with main functionality of the tool"""
import csv
import datetime
import logging
import os
import platform
import shutil
import sys
import webbrowser
from pathlib import Path

import jinja2

logging_level = os.environ.get("DEBUG_LEVEL")
logging.basicConfig(level=logging_level if logging_level else "INFO")
from stock_summary.library import (
    convert_currency,
    export_data,
    get_dividend_sum,
    get_dividend_summary,
    get_entries_summary,
    get_exchange_rates,
    get_pair_prices,
    get_pairs,
    get_plot_html,
    import_data,
    prepare_portfolio_data,
    rewrite_data_files,
    save_dividend,
    save_entry,
    validate_date,
)
from stock_summary.parsers import (
    add_entry_parser,
    dividend_parser,
    export_parser,
    import_parser,
)
from stock_summary.settings import (
    DIVIDEND_PATH,
    ENTRIES_PATH,
    INDEX_HTML_FILE,
    MAIN_CSS_FILE,
    PORTFOLIO_PATH,
    SETTINGS_PATH,
    TOKEN_PATH,
)


def generate_portfolio_main() -> None:
    """Generates portfolio for actual time and entered entries."""
    conversion_rates = get_exchange_rates()
    pairs = get_pairs()
    prices = get_pair_prices(pairs)
    with open(ENTRIES_PATH, newline="", encoding="utf-8") as csvfile:
        entries_reader = csv.reader(csvfile, delimiter=" ", quotechar="|")
        init_value: float = 0
        curr_value: float = 0
        next(entries_reader)
        for row in entries_reader:
            if not row:
                continue
            count = float(row[2])
            conversion_rate = conversion_rates[prices[row[1]]["currency"]]
            init_value += float(row[4])
            curr_value += count * prices[row[1]]["regularMarketPrice"] * conversion_rate
    with open(PORTFOLIO_PATH, "a", encoding="utf-8") as result_file:
        now = datetime.datetime.now()
        result_file.write(
            f"{now.strftime('%d/%m/%y')} {curr_value} "
            f"{curr_value - init_value + get_dividend_sum()}\n"
        )
    logging.info(
        "Portfolio with cost basis %s and profit %s generated and added.",
        curr_value,
        curr_value - init_value,
    )


def generate_html_main() -> None:
    """
    Generates HTML and executes it in your browser.
    """
    summary_records = list(get_entries_summary().values())
    dividend_summary = list(get_dividend_summary().values())

    portfolio_data = prepare_portfolio_data()
    plot_html = get_plot_html(portfolio_data)
    environment = jinja2.Environment()
    with open(
        Path(__file__).parent.resolve() / "html_files" / "jinja.html",
        "r",
        encoding="utf-8",
    ) as html_template:
        template = environment.from_string(html_template.read())
    with open(INDEX_HTML_FILE, "w", encoding="utf-8") as index_file:
        index_file.write(
            template.render(
                plot_html=plot_html, records=summary_records, dividends=dividend_summary
            )
        )
    shutil.copy2(
        Path(__file__).parent.resolve() / "html_files" / "main.css", MAIN_CSS_FILE
    )
    logging.info(f"Index html file successfully saved to {INDEX_HTML_FILE}")
    prepend_str = ""
    if platform.system().lower() == "darwin":
        prepend_str = "file:///"
    webbrowser.open(f"{prepend_str}{INDEX_HTML_FILE}")


def add_entry_main() -> None:
    """
    Root function for the add entry argument from the command line.
    """
    parser = add_entry_parser()
    (options, _) = parser.parse_args()
    if not options.stock or not options.date or not options.count or not options.price:
        logging.error("You have to enter all needed params")
        raise ValueError("You have to enter all needed params")
    pair = options.stock.strip()
    try:
        date = validate_date(options.date)
        count = float(options.count)
        price = float(options.price)
    except TypeError as err:
        raise RuntimeError("parameters have bad types, please try again") from err
    currency = get_pair_prices(get_pairs())[options.stock]["currency"]
    converted_amount = convert_currency(date, currency, "CZK", count * price)
    save_entry(
        options.date, pair, options.count, options.price, converted_amount
    )
    logging.info(
        "Entry with date %s , stock %s, count %s , price %s successfully added.",
        options.date,
        options.stock,
        options.count,
        options.price,
    )


def export_data_main() -> None:
    """Main function for export data command."""
    parser = export_parser()
    (options, _) = parser.parse_args()
    if not options.directory:
        logging.error("You need to pass the directory for the output.")
        sys.exit(1)
    export_data(Path(options.directory))


def import_data_main() -> None:
    """Main function for import data command."""
    parser = import_parser()
    (options, _) = parser.parse_args()
    if (
        options.portfolio or options.entries or options.dividends
    ) and options.initialize:
        logging.error(
            "Using rewrite option with entries and portfolio options, no effect."
        )
        sys.exit(1)
    if options.initialize and options.confirmation:
        rewrite_data_files(rewrite=True)
        logging.info("Data files initialized with empty files with correct headers.")
        return
    if not options.confirmation:
        user_confirmation = input(
            "You will rewrite your actual saved data, are you sure to proceed? "
            "Type Y: "
        )
        if not user_confirmation.lower() == "y":
            logging.error("Action canceled, ending without any action.")
            sys.exit(1)
    if options.portfolio:
        import_data(Path(options.portfolio), PORTFOLIO_PATH)
        logging.info(
            f"Portfolio {options.portfolio} successfully updated to {PORTFOLIO_PATH}"
        )
    if options.entries:
        import_data(Path(options.entries), ENTRIES_PATH)
        logging.info(
            f"Entries {options.entries} successfully updated to {ENTRIES_PATH}"
        )
    if options.dividends:
        import_data(Path(options.dividends), DIVIDEND_PATH)
        logging.info(
            f"Dividends {options.dividends} successfully updated to {DIVIDEND_PATH}"
        )


def save_token_main() -> None:
    """Main function for save token command."""
    token = sys.argv[2]
    os.makedirs(SETTINGS_PATH, exist_ok=True)
    with open(TOKEN_PATH, "w", encoding="utf-8") as token_file:
        token_file.write(token)
    logging.info(f"Token successfully saved to {TOKEN_PATH}")


def add_dividend_main() -> None:
    """
    Root function for the dividend argument from the command line.
    """
    parser = dividend_parser()
    (options, _) = parser.parse_args()
    if not options.stock or not options.date or not options.amount:
        logging.error("You have to enter all needed params")
        raise ValueError("You have to enter all needed params")
    pair = options.stock.strip()
    try:
        date = validate_date(options.date)
        amount = float(options.amount)
    except TypeError as err:
        raise RuntimeError("parameters have bad types, please try again") from err
    save_dividend(date, pair, amount)
    logging.info(
        "Entry with date %s , stock %s, amount %s .",
        options.date,
        options.stock,
        options.amount,
    )


def print_main_help() -> None:
    """Prints main help"""
    print(
        "Available commands:\n\n"
        "add-entry [opts] - add entry for current date, stock, count and price\n\n"
        "generate-portfolio [opts] - generates actual value of your portfolio in CZK and "
        "percentage move from the start of your investments\n"
        "generate-html [opts] - generates summary page from all current data\n\n"
        "import-data [opts] - imports data from your custom files\n\n"
        "export-data [opts] - exports data to your directory\n\n"
        "save-token (token) - save your token to rapidAPI\n\n"
        "add-dividend [opts] - add dividend for current pair and date\n\n"
    )


def main() -> None:
    """Main function."""
    try:
        rewrite_data_files()
        if sys.argv[1] == "generate-html":
            generate_html_main()
        elif sys.argv[1] == "add-entry":
            add_entry_main()
        elif sys.argv[1] == "generate-portfolio":
            generate_portfolio_main()
        elif sys.argv[1] == "export-data":
            export_data_main()
        elif sys.argv[1] == "import-data":
            import_data_main()
        elif sys.argv[1] == "save-token":
            save_token_main()
        elif sys.argv[1] == "add-dividend":
            add_dividend_main()
        elif sys.argv[1] == "-h" or sys.argv[1] == "--help":
            print_main_help()
        else:
            logging.error(
                "Invalid first command, use option from: 'retrain-model','make-analysis"
                ",'retrain-model','get-result'"
            )
            sys.exit(1)
    except (RuntimeError, ValueError) as err:
        logging.error(err)
        raise err
    sys.exit(0)


# Press the green button in the gutter to run the script.
if __name__ == "__main__":
    main()



""" library functions """
import csv
import datetime
import json
import logging
import os
import pathlib
import shutil
import sys
from functools import lru_cache
from pathlib import Path
from typing import Any, Dict, List, Optional

import pandas as pd
import plotly.graph_objects as go
import requests
from plotly.subplots import make_subplots

from stock_summary.settings import (
    DATA_PATH,
    DIVIDEND_PATH,
    ENTRIES_PATH,
    EXCHANGE_RATE_HEADERS,
    EXCHANGE_RATE_URL,
    INIT_DATASETS_PATH,
    PORTFOLIO_PATH,
    STOCK_PRICE_HEADERS,
    STOCK_PRICE_URL,
    Dividend,
    PairResponse,
    SummaryDict,
)


def check_pair_responses(pairs: List[PairResponse]) -> None:
    """Do same basic checks on incoming responses from API for stock prices."""
    for pair in pairs:
        if pair["regularMarketPrice"] <= 0:
            raise ValueError(f"Entered symbol {pair['symbol']} has invalid price <=0.")
    logging.debug(f"Successfully checked responses for {pairs}")


@lru_cache()
def get_exchange_rates(
    date: Optional[datetime.datetime] = None, base_pair: str = "CZK"
) -> Dict[str, float]:
    """Returns dict with actual values for conversions between other currencies and CZK"""
    url = (
        f"{EXCHANGE_RATE_URL}/latest"
        if date is None
        else f"{EXCHANGE_RATE_URL}/{date.strftime('%Y-%m-%d')}"
    )
    response = requests.request(
        "GET",
        url,
        timeout=10,
        headers=EXCHANGE_RATE_HEADERS,
        params={"base": base_pair},
    )
    exchange_dict = {}
    for key, value in json.loads(response.text)["rates"].items():
        exchange_dict[key] = 1 / value
    logging.debug("Returning exchange dict %s", exchange_dict)
    return exchange_dict


def get_pair_prices(pairs: List[str]) -> Dict[str, PairResponse]:
    """
    Search for price on url and xpath, if error occurs, raises error.
    """
    url = f"{STOCK_PRICE_URL}/{','.join(pairs)}"

    response = requests.request("GET", url, headers=STOCK_PRICE_HEADERS, timeout=10)
    logging.debug("Requesting URL %s with response %s", url, response)
    result_list: List[PairResponse] = json.loads(response.text)
    check_pair_responses(result_list)
    result_dict = {}
    for result in result_list:
        result_dict[result["symbol"]] = result
    logging.debug(f"Returning pair_prices {result_dict}")
    return result_dict


def validate_date(date_text: str) -> datetime.datetime:
    """Validates date to our custom format."""
    try:
        date = datetime.datetime.strptime(date_text, "%d/%m/%Y")
        logging.debug(f"Validated data for {date_text}")
        return date
    except ValueError as err:
        raise ValueError("Incorrect data format, should be DD/MM/YYYY") from err


def get_entries_summary(
    entries_path: pathlib.Path = ENTRIES_PATH,
) -> Dict[str, SummaryDict]:
    """
    Returns entries summary with keys as stock symbols and values as dicts with all important
    values (see TypedDict) in settings.
    """
    entries_dict: Dict[str, SummaryDict] = {}
    with open(entries_path, newline="", encoding="utf-8") as csvfile:
        entries = csv.reader(csvfile, delimiter=" ", quotechar="|")
        next(entries)
        for entry in entries:
            if entry[1] not in entries_dict:
                entries_dict[entry[1]] = {
                    "symbol": entry[1],
                    "count": 0,
                    "cost_basis": 0,
                    "actual_basis": 0,
                    "currency": "",
                    "actual_price": 0,
                }
            entries_dict[entry[1]]["count"] += float(entry[2])
            entries_dict[entry[1]]["cost_basis"] += float(entry[4])
    exchange_rates = get_exchange_rates()
    pair_prices = get_pair_prices(list(entries_dict.keys()))
    for key, value in entries_dict.items():
        value["currency"] = pair_prices[key]["currency"]
        value["actual_price"] = pair_prices[key]["regularMarketPrice"]
        value["actual_basis"] = (
            value["count"] * pair_prices[key]["regularMarketPrice"]
        ) * exchange_rates[pair_prices[key]["currency"]]
    logging.debug(f"Returning entries summary {entries_dict}")
    return entries_dict


def prepare_portfolio_data() -> Any:
    """Prepares portfolio data and returns them as pandas dataset"""
    dataset = pd.read_csv(PORTFOLIO_PATH, sep=" ")
    dataset["DATE"] = pd.to_datetime(dataset["DATE"], format="%d/%m/%y")
    return dataset


def get_plot_html(dataset: Any) -> Any:
    """Exports plot as HTML and returns it."""
    # Create figure with secondary y-axis
    fig = make_subplots(specs=[[{"secondary_y": True}]])

    # Add traces
    fig.add_trace(
        go.Scatter(
            x=dataset["DATE"], y=dataset["TOTAL_PRICE"], name="AKTUÁLNÍ HODNOTA"
        ),
        secondary_y=False,
    )

    fig.add_trace(
        go.Scatter(x=dataset["DATE"], y=dataset["PROFIT"], name="PROFIT"),
        secondary_y=True,
    )

    # Add figure title
    fig.update_layout(title_text="Přehled portfolia v čase")

    # Set x-axis title
    fig.update_xaxes(title_text="Čas")

    # Set y-axes titles
    fig.update_yaxes(title_text="<b>AKTUÁLNÍ HODNOTA</b>", secondary_y=False)
    fig.update_yaxes(title_text="<b>PROFIT</b>", secondary_y=True)

    fig.show()
    return fig.to_html()


def rewrite_data_files(rewrite: bool = False) -> None:
    """Check if files exist in memory, if not then creates them with initialized headers."""
    os.makedirs(DATA_PATH, exist_ok=True)
    if rewrite or not os.path.exists(ENTRIES_PATH):
        shutil.copy2(
            f"{INIT_DATASETS_PATH.joinpath('entries')}",
            ENTRIES_PATH,
        )
        logging.debug(f"Created init entries file {ENTRIES_PATH}")
    if rewrite or not os.path.exists(PORTFOLIO_PATH):
        shutil.copy2(
            f"{INIT_DATASETS_PATH.joinpath('portfolio')}",
            PORTFOLIO_PATH,
        )
        logging.debug(f"Created init portfolio file {ENTRIES_PATH}")
    if rewrite or not os.path.exists(DIVIDEND_PATH):
        shutil.copy2(
            f"{INIT_DATASETS_PATH.joinpath('dividends')}",
            DIVIDEND_PATH,
        )
        logging.debug(f"Created init portfolio file {DIVIDEND_PATH}")


def import_data(from_file: pathlib.Path, to_file: pathlib.Path) -> None:
    """
    Imports data from entry file to target file. If target file already exists, then
    asks user for confirmation
    """
    shutil.copy2(from_file.resolve(), to_file.resolve())
    logging.debug(
        f"Successfully moved data from {from_file.resolve()} to {to_file.resolve()}"
    )


def export_data(directory: pathlib.Path) -> None:
    """
    Exports all data files to target directory, creates recursively, if doesn't exist.
    """
    path = directory.resolve()
    os.makedirs(path, exist_ok=True)
    shutil.copy2(ENTRIES_PATH, f"{path.joinpath(ENTRIES_PATH.parts[-1]).resolve()}")
    shutil.copy2(PORTFOLIO_PATH, f"{path.joinpath(PORTFOLIO_PATH.parts[-1]).resolve()}")
    shutil.copy2(DIVIDEND_PATH, f"{path.joinpath(DIVIDEND_PATH.parts[-1]).resolve()}")


def save_dividend(date: datetime.datetime, stock: str, amount: float) -> None:
    """ Saves dividend into the file"""
    currency = get_pair_prices([stock])[stock]["currency"]
    converted_amount = convert_currency(date, currency, "CZK", amount)
    with open(DIVIDEND_PATH, "a", newline="", encoding="utf-8") as csvfile:
        csv_writer = csv.writer(csvfile, delimiter=" ", quotechar="|")
        csv_writer.writerow(
            [date.strftime("%d/%m/%Y"), stock, amount, converted_amount]
        )
    logging.debug(
        f"Dividend date: {date} stock: {stock} amount: {amount} "
        f"converted_amount: {converted_amount} saved to {DIVIDEND_PATH}"
    )


def convert_currency(
    date: datetime.datetime, from_curr: str, to_curr: str, amount: float
) -> float:
    """ Convert currency by rate from the given date"""
    exchange_rates = get_exchange_rates(date, to_curr)
    return amount * exchange_rates[from_curr]


def get_dividend_summary() -> Dict[str, Dividend]:
    """Returns dividend summary"""
    dividend_summary: Dict[str, Dividend] = {}
    with open(DIVIDEND_PATH, newline="", encoding="utf-8") as csvfile:
        dividends = csv.reader(csvfile, delimiter=" ", quotechar="|")
        next(dividends)
        for dividend in dividends:
            if dividend[1] not in dividend_summary:
                dividend_summary[dividend[1]] = {
                    "symbol": dividend[1],
                    "value": 0,
                    "converted_value": 0,
                    "currency": "",
                }
            dividend_summary[dividend[1]]["value"] += float(dividend[2])
            dividend_summary[dividend[1]]["converted_value"] += float(dividend[3])
    pair_prices = get_pair_prices(list(dividend_summary.keys()))
    for key, value in dividend_summary.items():
        value["currency"] = pair_prices[key]["currency"]
    return dividend_summary


def get_dividend_sum(dividend_path: pathlib.Path = DIVIDEND_PATH) -> float:
    """Returns sum of the all dividends."""
    with open(dividend_path, newline="", encoding="utf-8") as csvfile:
        dividend_lines = csv.reader(csvfile, delimiter=" ", quotechar="|")
        next(dividend_lines)
        sum_value = 0.0
        for dividend in dividend_lines:
            sum_value += float(dividend[3])
    return sum_value


def get_pairs(entries_path: pathlib.Path = ENTRIES_PATH) -> List[str]:
    """Returns list of pairs."""
    with open(entries_path, newline="", encoding="utf-8") as csvfile:
        pair_lines = csv.reader(csvfile, delimiter=" ", quotechar="|")
        next(pair_lines)
        pairs = [pair[1].strip() for pair in pair_lines if pair]
        logging.debug("Getting pairs %s", pairs)
        return list(set(pairs))


def save_entry(
    date: str, stock: str, count: str, price: str, converted_amount: float
) -> None:
    """Save entries to CSV file."""
    with open(ENTRIES_PATH, "a", newline="", encoding="utf-8") as csvfile:
        csv_writer = csv.writer(csvfile, delimiter=" ", quotechar="|")
        csv_writer.writerow([date, stock, count, price, converted_amount])
    logging.debug(
        f"Entry date: {date} stock: {stock} count: {count} "
        f"price: {price} saved to {ENTRIES_PATH}"
    )



""" file with settings """
import logging
import pathlib
from enum import Enum
from typing import TypedDict

import appdirs

DATA_PATH = pathlib.Path(appdirs.user_data_dir("stock_summary")).resolve()
SETTINGS_PATH = pathlib.Path(appdirs.user_config_dir("stock_summary")).resolve()
INIT_DATASETS_PATH = (
    pathlib.Path(__file__).parent.resolve().joinpath("init_datasets").resolve()
)


class LoggingSettings(Enum):
    """Enum which saves settings for logging"""

    OUTPUT_FILE = "tmp.log"
    LOGGING_LEVEL = logging.DEBUG


class PairResponse(TypedDict):
    """Pair response that we get from API for each pair."""

    symbol: str
    regularMarketPrice: float
    currency: str


class SummaryDict(TypedDict):
    """This dict is used to summarize entries for view Jinja HTML"""

    symbol: str
    actual_price: float
    actual_basis: float
    cost_basis: float
    count: float
    currency: str


class Dividend(TypedDict):
    """THis dict is used to summarize dividends for view Jinja HTML"""

    currency: str
    symbol: str
    converted_value: float
    value: float


ENTRIES_PATH = DATA_PATH.joinpath("entries").resolve()
PORTFOLIO_PATH = DATA_PATH.joinpath("portfolio").resolve()
DIVIDEND_PATH = DATA_PATH.joinpath("dividends").resolve()
INDEX_HTML_FILE = DATA_PATH.joinpath("index.html").resolve()
MAIN_CSS_FILE = DATA_PATH.joinpath("main.css").resolve()
TOKEN_PATH = SETTINGS_PATH.joinpath("token").resolve()
try:
    with open(TOKEN_PATH, "r", encoding="utf-8") as token_file:
        API_TOKEN = token_file.read().strip()
except FileNotFoundError:
    API_TOKEN = ""

EXCHANGE_RATE_URL = "https://fixer-fixer-currency-v1.p.rapidapi.com"
EXCHANGE_RATE_HEADERS = {
    "X-RapidAPI-Key": API_TOKEN,
    "X-RapidAPI-Host": "fixer-fixer-currency-v1.p.rapidapi.com",
}

STOCK_PRICE_URL = "https://yahoo-finance15.p.rapidapi.com/api/yahoo/qu/quote"
STOCK_PRICE_HEADERS = {
    "X-RapidAPI-Key": API_TOKEN,
    "X-RapidAPI-Host": "yahoo-finance15.p.rapidapi.com",
}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['stock_summary']

package_data = \
{'': ['*'],
 'stock_summary': ['demo_datasets/*', 'html_files/*', 'init_datasets/*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0',
 'jinja2>=3.1.2,<4.0.0',
 'pandas>=1.5.2,<2.0.0',
 'plotly>=5.11.0,<6.0.0',
 'requests>=2.28.1,<3.0.0']

entry_points = \
{'console_scripts': ['stock_summary_tool = stock_summary.main:main']}

setup_kwargs = {
    'name': 'stock-summary-tool',
    'version': '0.1.1',
    'description': 'Tool for tracking of your investments and your actual portfolio',
    'long_description': "# Stock summary tool\n\n### CREATE YOUR ENVIRONMENT\n1. Create virtual environment that you will use for the project and activate it (python3.8+ required):\n```\npython3 -m venv my_venv/\nsource my_venv/bin/activate\n```\n2. Install the package: \n```\npip3 install stock_summary_tool\n```\n3. Generate and save your token:\n   1. Register or log in to the page.\n   2. Go to https://rapidapi.com/ and register.\n   3. Subscribe to these APIs and obtain your API key:\n      1. https://rapidapi.com/sparior/api/yahoo-finance15\n      2. https://rapidapi.com/fixer/api/fixer-currency\n   4. Save your key for the project:\n   ```\n   stock_summary_tool save-token <YOUR_TOKEN>\n   ```\n### DEMO\n\n1. You can download demo datasets and import them:\n   ```\n   stock_summary_tool import-data -y -e <PATH_TO_DEMO_ENTRIES> -p <PATH_TO_DEMO_PORTFOLIO)\n   ```\n2. You can generate-html (it should open automatically in your browser):\n   ```\n   stock_summary_tool generate-html\n   ```\n3. You can update your portoflio by actual cost and generate again HTML page:\n   ```\n   stock_summary_tool generate-portfolio\n   stock_summary_tool generate-html\n   ```\n\n### CREATE YOUR PORTFOLIO\n\n1. Refresh data to empty files:\n   ```\n   stock_summary_tool import-data -y --rewrite\n   ```\n2. Add your entries (example) - stock symbol, date, count of stocks, price (sell entries are also supported, just add '-' sign before count):\n   ```\n   stock_summary_tool add-entry -s BOTZ.MI -d 12/01/2023 -c 20 -p 30\n   ```\n3. You can enter also your dividends (amount is in original currency):\n   ```\n   stock_summary_tool add-dividend -s BOTZ.MI -d 12/01/2023 -a 10 \n   ```\n4. After you add your entries and dividends, generate actual portfolio and HTML:\n   ```\n   stock_summary_tool generate-portfolio\n   stock_summary_tool generate-html\n   ```\n5. You can also export your data and share them across multiple systems (by importing them again):\n   ```\n   stock_summary_tool export-data -d <DIRECTORY_FOR_EXPORT>\n   ```\n\n### HTML tutorial\n\n*You can open example summary stock_summary/demo_datasets/index.html Right now, there is supported only czech language and CZK currency is taken as base.*\n\nYou can see plot with your actual investments in stocks, and also your profit (generated from portfolio file). Below you can see your actual holdings and \nstatistics about them. Only actual holdings with >0 count are shown. The last table is for dividends.\n\n### Rules about generating portfolio and balance\n1. Entries are converted to the base currency with conversion rate for the execution day.\n2. Dividends are converted to the base currency with conversion rate for the execution day.\n3. Value of your portfolio for the current day is counted as sum of your holdings for the day. (converted to base currency)\n4. Profit is comparison of your invested amount with dividends and your actual holdings. If you sell some stocks, profit stays same, only value of your portfolio goes down. Same with buy entries (portfolio up, profit stays same). If you get some dividends, it grows your profit by that amount.\n5. ONCE AGAIN: All amounts are automatically converted to base currency by exchange rate of the execution day. It doesn't matter if you convert them or not. Right now it's out of scope of the tool.\n\n### Plans for the future\n1. Adding option for fees to the operations.\n2. Supporting more languages and base currencies.\n3. Adding backward possibility to generate portfolio and no need to generate it manually anymore (blocked by higher number of API calls and subscription)\n4. Support for cloud storage (easy setup and option to use tool across more systems without manual import/export)\n5. Adding option to track other investments except stocks/cryptocurrencies/dividends.\n\nBe free to open issue or ask me, if you want to know something or you want to help with the project.\n\n",
    'author': 'Simon Foucek',
    'author_email': 'foucek.simon@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<3.12',
}


setup(**setup_kwargs)
